/*
 * Licensed to CRATE Technology GmbH ("Crate") under one or more contributor
 * license agreements.  See the NOTICE file distributed with this work for
 * additional information regarding copyright ownership.  Crate licenses
 * this file to you under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.  You may
 * obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.  See the
 * License for the specific language governing permissions and limitations
 * under the License.
 *
 * However, if you have executed another commercial license agreement
 * with Crate these terms will supersede the license and you may use the
 * software solely pursuant to the terms of the relevant commercial agreement.
 */

package io.crate.planner;

import java.util.UUID;

/**
 * A plan with an empty result
 */
public class NoopPlan implements Plan {

    public enum Type {
        QUERY_RESULT,
        ROW_COUNT,
    }

    private final UUID id;
    private final Type type;

    public NoopPlan(UUID id) {
        this.id = id;
        this.type = Type.QUERY_RESULT;
    }

    public NoopPlan(UUID id, Type type) {
        this.id = id;
        this.type = type;
    }

    @Override
    public <C, R> R accept(PlanVisitor<C, R> visitor, C context) {
        return visitor.visitNoopPlan(this, context);
    }

    @Override
    public UUID jobId() {
        return id;
    }

    public Type getType() {
        return type;
    }
}
